| break_function_custom | R Documentation |
Creates axis breaks based on maximum value with custom logic for determining break intervals based on magnitude.
break_function_custom(xmax)
xmax |
Maximum value for axis |
Numeric vector of break positions
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.