covnm: Match coefficient names to covariate names

View source: R/helper.R

covnmR Documentation

Match coefficient names to covariate names

Description

Matches model coefficient names (with factor levels) back to original covariate names from the model call. Handles cases where one factor name is a subset of another.

Usage

covnm(betanames, call)

Arguments

betanames

Vector of coefficient names from model

call

Vector of covariate names from model formula

Value

Vector of matched covariate names


reportRmd documentation built on March 20, 2026, 5:06 p.m.