Retrieve columns number from spreadsheet columns specified as unquoted letters

excelCol(...)

Arguments

...

unquoted excel column headers (i.e. excelCol(A,CG,AA)) separated by commas

Value

a numeric vector corresponding to columns in a spreadsheet

Examples

## Find the column numbers for excel columns AB, CE and BB
excelCol(AB,CE,bb)
#> AB CE BB 
#> 28 83 54 
## Get the columns between A and K and Z
excelCol(A-K,Z)
#>  [1]  1  2  3  4  5  6  7  8  9 10 11 26