get_event_counts: Extract event counts from a fitted model

View source: R/autosum.R

get_event_countsR Documentation

Extract event counts from a fitted model

Description

S3 generic to extract event and sample size counts from a fitted model.

Usage

get_event_counts(model)

Arguments

model

A fitted model object.

Value

A named list with event count information, or NULL.


reportRmd documentation built on March 20, 2026, 5:06 p.m.