| matchdata | R Documentation |
Attempts to identify the data frame object used in a model call by searching the global environment.
matchdata(dataArg)
dataArg |
Data argument from model call |
Character string of data frame name, or NULL if not found
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.