autoreg: Fit a regression model based on response type

View source: R/autoreg.R

autoregR Documentation

Fit a regression model based on response type

Description

S3 generic that dispatches to the appropriate model fitting function based on the class of the response variable.

Usage

autoreg(
  response,
  data,
  x_var,
  id = NULL,
  strata = "",
  family = NULL,
  offset = NULL,
  corstr = "independence"
)

Arguments

response

The response variable (used for S3 dispatch).

data

A data frame containing the model data.

x_var

Character string of the predictor variable name.

id

Optional subject ID for GEE models.

strata

Optional stratification variable.

family

Optional family for GLM models.

offset

Optional offset term.

corstr

Correlation structure for GEE models (default "independence").

Value

A fitted model object.


reportRmd documentation built on March 20, 2026, 5:06 p.m.