calculate_and_add_time_specific_estimates.RdCalculate survival/CIF at specific time points and add to labels
calculate_and_add_time_specific_estimates(
sfit = NULL,
fit = NULL,
stratalabs,
type = "KM",
plot.event = 1,
set.time.text = NULL,
set.time = NULL,
set.time.line = FALSE,
set.time.CI = FALSE,
set.time.digits = 3
)Survival fit object (for KM)
CIF fit object
Strata labels
Model type
Events to plot (for CIF)
Text label for time points
Time points to evaluate
boolean to specify if you want the survival added as lines to the plot at a specified point
Whether to include CI
Number of digits