| calculate_and_add_time_specific_estimates | R Documentation |
Calculate survival/CIF at specific time points and add to labels
calculate_and_add_time_specific_estimates(
sfit = NULL,
fit = NULL,
stratalabs,
type = "KM",
plot.event = 1,
set.time.text = NULL,
set.time = NULL,
set.time.line = FALSE,
set.time.CI = FALSE,
set.time.digits = 3
)
sfit |
Survival fit object (for KM) |
fit |
CIF fit object |
stratalabs |
Strata labels |
type |
Model type |
plot.event |
Events to plot (for CIF) |
set.time.text |
Text label for time points |
set.time |
Time points to evaluate |
set.time.line |
boolean to specify if you want the survival added as lines to the plot at a specified point |
set.time.CI |
Whether to include CI |
set.time.digits |
Number of digits |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.