| covnm | R Documentation |
Matches model coefficient names (with factor levels) back to original covariate names from the model call. Handles cases where one factor name is a subset of another.
covnm(betanames, call)
betanames |
Vector of coefficient names from model |
call |
Vector of covariate names from model formula |
Vector of matched covariate names
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.