| get_event_counts | R Documentation |
S3 generic to extract event and sample size counts from a fitted model.
get_event_counts(model)
model |
A fitted model object. |
A named list with event count information, or NULL.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.