| order_forest_data | R Documentation |
Orders variables by their maximum estimate (descending) and levels within variables by their original order, with reference levels first.
order_forest_data(tab)
tab |
data frame prepared by prepare_forest_data |
When both Adjusted and Unadjusted rows are present, ordering is determined by the Adjusted estimates. When only Unadjusted rows are present (e.g., from forestplotUV), ordering uses those estimates directly.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.