outTable.RdOutput the table nicely to whatever format is appropriate. This is the output function used by the rm_* printing functions.
outTable(
tab,
row.names = NULL,
to_indent = numeric(0),
bold_headers = TRUE,
rows_bold = numeric(0),
bold_cells = NULL,
caption = NULL,
digits = getOption("reportRmd.digits", 2),
align,
applyAttributes = TRUE,
keep.rownames = FALSE,
nicenames = TRUE,
fontsize,
chunk_label,
format = NULL,
header_above = NULL
)a table to format
a string specifying the column name to assign to the rownames. If NULL (the default) then rownames are removed.
numeric vector indicating which rows to indent in the first column.
boolean indicating if the column headers should be bolded
numeric vector indicating which rows to bold
array indices indicating which cells to bold. These will be in addition to rows bolded by rows_bold.
table caption
number of digits to round numeric columns to, either a single number or a vector corresponding to the number of numeric columns in tab
string specifying column alignment, defaults to left alignment of the first column and right alignment of all other columns. The align argument accepts a single string with 'l' for left, 'c' for centre and 'r' for right, with no separations. For example, to set the left column to be centred, the middle column right-aligned and the right column left aligned use: align='crl'
boolean indicating if the function should use to_indent and bold_cells formatting attributes. This will only work properly if the dimensions of the table output from rm_covsum, rm_uvsum etc haven't changed.
should the row names be included in the output
boolean indicating if you want to replace . and _ in strings with a space
PDF/HTML output only, manually set the table fontsize
only used knitting to Word docs to allow cross-referencing
if specified ('html','latex') will override the global pandoc setting
a named numeric vector specifying an extra header row
above the column names, where the names are the labels and the values are
the number of columns each label should span. For example,
c(" " = 1, "Group A" = 2, "Group B" = 2) will leave the first
column blank, then span "Group A" over the next 2 columns, and
"Group B" over the following 2. For HTML and PDF output the header is
rendered as a true spanning row via kableExtra. For Word output the
labels are prepended as the first data row of the table (pandoc
markdown does not support cell merging).
A character vector of the table source code, unless tableOnly=TRUE in which case a data frame is returned
Entire rows can be bolded, or specific cells. Currently indentation refers to the first column only. By default, underscores in column names are converted to spaces. To disable this set nicenames to FALSE